from setuptools import setup

setup(name='NorBi_distribution',
      version='1.10',
      description='Gaussian and Binomial distributions',
      packages=['NorBi_distribution'],
      author='Nneamaka chalokwu',
      author_email ='chalokwun@gmail.com',
      zip_safe=False)
